==> ae_kivy_qr_displayer-0.1.3.tar.gz: ae_kivy_qr_displayer-0.1.3/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
  All changes will be deployed automatically to all the portions of this namespace package.
-->
# kivy_qr_displayer portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_qr_displayer/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_qr_displayer)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes for to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_qr_displayer/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_qr_displayer/coverage/ae_kivy_qr_displayer_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_qr_displayer/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_qr_displayer/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_qr_displayer/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_qr_displayer/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_qr_displayer)](
    https://libraries.io/pypi/ae-kivy-qr-displayer)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/#files)


## installation


Execute the following command for to use the ae.kivy_qr_displayer module in your
application. It will install ae.kivy_qr_displayer into your python (virtual) environment:
 
```shell script
pip install ae-kivy-qr-displayer
```

If you instead want to contribute to this portion then first fork
[the ae_kivy_qr_displayer repository at GitLab](https://gitlab.com/ae-group/ae_kivy_qr_displayer "ae.kivy_qr_displayer code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_qr_displayer):

```shell script
pip install -e .[dev]
```

The last command will install this module portion into your virtual environment, along with
the tools you need to develop and run tests or for to extend the portion documentation.
For to contribute only to the unit tests or the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

More info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_qr_displayer.html#module-ae.kivy_qr_displayer
"ae_kivy_qr_displayer documentation").

<!-- Common files version 0.1.66 deployed version 0.1.0 (with 0.1.66)
     to https://gitlab.com/ae-group as ae_kivy_qr_displayer module as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-qr-displayer as namespace portion ae-kivy-qr-displayer.
-->

==> ae_kivy_qr_displayer-0.2.6.tar.gz: ae_kivy_qr_displayer-0.2.6/README.md <==
<!--
  THIS FILE IS EXCLUSIVELY MAINTAINED IN THE NAMESPACE ROOT PACKAGE. CHANGES HAVE TO BE DONE THERE.
-->
# kivy_qr_displayer portion of ae namespace package

[![GitLabPipeline](https://img.shields.io/gitlab/pipeline/ae-group/ae_kivy_qr_displayer/master?logo=python)](
    https://gitlab.com/ae-group/ae_kivy_qr_displayer)
[![PyPIVersion](https://img.shields.io/pypi/v/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/#history)

>The portions (modules and sub-packages) of the Application Environment for Python are within
the `ae` namespace and are providing helper methods and classes to develop
full-featured applications with Python.

[![Coverage](https://ae-group.gitlab.io/ae_kivy_qr_displayer/coverage.svg)](
    https://ae-group.gitlab.io/ae_kivy_qr_displayer/coverage/ae_kivy_qr_displayer_py.html)
[![MyPyPrecision](https://ae-group.gitlab.io/ae_kivy_qr_displayer/mypy.svg)](
    https://ae-group.gitlab.io/ae_kivy_qr_displayer/lineprecision.txt)
[![PyLintScore](https://ae-group.gitlab.io/ae_kivy_qr_displayer/pylint.svg)](
    https://ae-group.gitlab.io/ae_kivy_qr_displayer/pylint.log)

[![PyPIImplementation](https://img.shields.io/pypi/implementation/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIPyVersions](https://img.shields.io/pypi/pyversions/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIWheel](https://img.shields.io/pypi/wheel/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIFormat](https://img.shields.io/pypi/format/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/)
[![PyPIStatus](https://img.shields.io/pypi/status/ae_kivy_qr_displayer)](
    https://libraries.io/pypi/ae-kivy-qr-displayer)
[![PyPIDownloads](https://img.shields.io/pypi/dm/ae_kivy_qr_displayer)](
    https://pypi.org/project/ae-kivy-qr-displayer/#files)


## installation


execute the following command to use the ae.kivy_qr_displayer sub-package in your
application. it will install ae.kivy_qr_displayer into your python (virtual) environment:
 
```shell script
pip install ae-kivy-qr-displayer
```

if you instead want to contribute to this portion then first fork
[the ae_kivy_qr_displayer repository at GitLab](https://gitlab.com/ae-group/ae_kivy_qr_displayer "ae.kivy_qr_displayer code repository"),
then pull it to your machine and finally execute the following command in the root folder
of this repository (ae_kivy_qr_displayer):

```shell script
pip install -e .[dev]
```

the last command will install this sub-package portion into your virtual environment, along with
the tools you need to develop and run tests or to extend the portion documentation.
to contribute only to the unit tests or to the documentation of this portion replace
the setup extras key `dev` in the above command with `tests` or `docs` respectively.


## namespace portion documentation

more info on the features and usage of this portion are available at
[ReadTheDocs](https://ae.readthedocs.io/en/latest/_autosummary/ae.kivy_qr_displayer.html#module-ae.kivy_qr_displayer
"ae_kivy_qr_displayer documentation").

<!-- common files version 0.2.77 deployed version 0.2.5 (with 0.2.77)
     to https://gitlab.com/ae-group as ae_kivy_qr_displayer sub-package as well as
     to https://ae-group.gitlab.io with CI check results as well as
     to https://pypi.org/project/ae-kivy-qr-displayer as namespace portion ae-kivy-qr-displayer.
-->
